---
eip: 1355
title: Ethash 1a
author: Paweł Bylica (@chfast), Jean M. Cyr (@jean-m-cyr)
discussions-to: https://ethereum-magicians.org/t/eip-1355-ethash-1a/1167
status: Withdrawn
type: Standards Track
category: Core
created: 2018-08-26
---

## Motivation

Provide minimal set of changes to Ethash algorithm to hinder and delay the adoption of ASIC based mining.

## Specification

1. Define hash function `fnv1a()` as
   ```python
   def fnv1a(v1, v2):
       return ((v1 ^ v2) * FNV1A_PRIME) % 2**32
   ```
   where `FNV1A_PRIME` is 16777499 or 16777639.
2. Change the hash function that determines the DAG item index in Ethash algorithm from `fnv()` to new `fnv1a()`.
   In [Main Loop](https://github.com/ethereum/wiki/wiki/Ethash#main-loop) change
   ```python
   p = fnv(i ^ s[0], mix[i % w]) % (n // mixhashes) * mixhashes
   ```
   to
   ```python
   p = fnv1a(i ^ s[0], mix[i % w]) % (n // mixhashes) * mixhashes
   ```

## Rationale

The usual argument for decentralization and network security.

Unless programmable, an ASIC is hardwired to perform sequential operations in a given order. fnv1a changes the order in which an exclusive-or and a multiply are applied, effectively disabling the current wave of ASICS. A second objective is minimize ethash changes to be the least disruptive, to facilitate rapid development, and to lower the analysis and test requirements. Minimizing changes to ethash reduces risk associated with updating all affected network components, and also reduces the risk of detuning existing GPUs. It's expected that this specific change would have no effect on existing GPU performance.

Changing fnv to fnv1a has no cryptographic implications. It is merely an efficient hash function with good dispersion characteristics used to scramble DAG indexing. We remain focused on risk mitigation by reducing the need for rigorous cryptographic analysis.


### FNV Primes

The 16777639 satisfies all requirements from [Wikipedia](https://en.wikipedia.org/wiki/Fowler%E2%80%93Noll%E2%80%93Vo_hash_function#FNV_prime).

The 16777499 is preferred by FNV authors but not used in the reference FNV implementation because of historical reasons.
See [A few remarks on FNV primes](http://www.isthe.com/chongo/tech/comp/fnv/index.html#fnv-prime).

## Copyright

This work is licensed under a [Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License](https://creativecommons.org/licenses/by-nc-sa/4.0/).
