---
eip: 2228
title: Canonicalize the name of network ID 1 and chain ID 1
author: William Entriken (@fulldecent)
discussions-to: https://github.com/ethereum/EIPs/issues/2228
status: Final
type: Informational
created: 2019-08-04
---

## Simple Summary

The Ethereum network with network ID 1 and chain ID 1 is named Ethereum Mainnet.

## Abstract

The name for the Ethereum network with network ID 1 and chain ID 1 shall be Ethereum Mainnet or just Mainnet. This is a proper noun.

This standard specifies the name for this network and provides reference examples in an effort to standardize the word choice and provide a common language for use to refer to this network.

## Motivation

The Ethereum network with network ID 1 and chain ID 1 is referenced using several conflicting names across EIPs, client implementations, and information published on the internet at large. In several locations, even documents written by the same author use inconsistent names to refer to the Ethereum network with network ID 1 and chain ID 1. Names in use at the time of this writing include:

* "main net"
* "mainnet"
* "Main net"
* "Mainnet"

## Specification

The network name for network ID 1 and chain ID 1 shall be Ethereum Mainnet, or just Mainnet if the context is known to be discussing Ethereum networks. This IS a proper noun. Several examples are given below which differentiate between usage of the name of the network versus a descriptive reference to the network.

Any name or word styling (i.e. capitalization of the letters) of the network which is inconsistent with the test cases cited below shall NOT be used.

### Trademark note

"Ethereum" is trademarked by the Ethereum Foundation. For more information on your obligations when mentioning "Ethereum", and possibly "Ethereum Mainnet", see:

* USPTO registration number 5110579 by Ethereum Foundation
* The note "you must not use [this mark] without the prior written permission of the Foundation" on the Ethereum Foundation website, Terms of Use page

## Rationale

Choosing common word use promotes interoperability of implementations and increases customer awareness. Also, it adds a sense of professionalism when customers see the same word and word styling (i.e. capitalization of letters) across different implementations.

Anybody that has travelled to certain countries and seen an "IPhone [sic]" repair store should immediately recognize that this is off-brand and unofficial. Likewise, the astute customer of Ethereum should recognize if they see the network referred to using inconsistent names in different software, so let's avoid this.

## Backwards Compatibility

- MetaMask previously used "Main Ethereum Network" in the account network chooser. MetaMask has been updated consistent with this EIP.

- References to Mainnet that are inconsistent with this specification are made in: [EIP-2](./eip-2.md), [EIP-779](./eip-779.md), [EIP-150](./eip-150.md), [EIP-155](./eip-155.md), [EIP-190](./eip-190.md), [EIP-225](./eip-225.md), [EIP-1013](./eip-1013.md), [EIP-2028](./eip-2028.md), and [EIP-2387](./eip-2387.md). For consistency, we recommend the editor will update EIPs to consistently use the name as specified in this EIP.

## Test Cases

### Examples referencing the name of the network ✅

> The contract was deployed to Ethereum Mainnet.

> Ethereum runs many applications, this Dapp was deployed to Mainnet.

No specification is made on whether Dapp, dapp, dApp, etc. is preferred.

> SWITCH TO MAINNET

This example shows a user interface which is in uppercase. To be semantically correct, this could be written in HTML as `<span style="text-transform: uppercase">Switch to Mainnet</span>`.

> switch to mainnet

This example shows a user interface which is in lowercase. To be semantically correct, this could be written in HTML as `<span style="text-transform: lowercase">Switch to Mainnet</span>`.

### Examples referencing the network in a descriptive way ✅

> Mainnet has ### times the number of transactions as the test networks.

### Examples of other correct word usage ✅

> The main network on Ethereum is Mainnet

This shows that "main" is used as a descriptive word, but Mainnet is the specific network which is having network ID 1 and chain ID 1.

### Examples of poor word choice (avoid this) ❌

> Deploy your contract to the Ethereum main network.

This is referring to a "main" network which is context-dependent. If you were reading this text on a page about Ethereum Classic, they would be referring to network ID 2 and chain ID 62. Therefore this word usage is less crisp. Do NOT use wording like this.

> Connect to mainnet.

These words literally mean nothing. The lowercase, not-proper-noun word "mainnet" is not a plain English word and it should not be in any dictionary. Do NOT use wording like this.

## Copyright

Copyright and related rights waived via [CC0](../LICENSE.md).
