---
eip: 2378
title: EIPs Eligible for Inclusion
author: James Hancock (@MadeofTin)
discussions-to: https://gitter.im/ethereum/EIPs
status: Stagnant
type: Meta
created: 2019-11-13
---

## Simple Summary

As part of an EIP centric forking model, this EIP tracks the first step in the approval process for any EIP to be included in a fork or upgrade. Specifically, the stage where the Core Developers vet the concept of an EIP and give a "green light" sufficient for EIP authors to move forward in development.

## Abstract

The pipeline for Core EIPs, per the EIP-Centric upgrade model, is as follows.
```
[ DRAFT ] -> [ ELLIGLE FOR INCLUSION ] -> [ IMPLEMENTATION ] -> [ TESTING ] -> [ ACCEPTED ] -> [ DEPLOYED ]
```

This EIP documents all EIPs marked as **Eligible For Inclusion** by the All Core Devs. Typically to reach this stage, an EIP must be discussed in brief on an AllCoreDevs Call and motioned by rough consenses to be moved to this stage. Any additions to this list are required to provide a link to the meeting notes when this discussion and decision took place.

The requirements for **Eligible for Inclusion** is that the AllCoreDevs, representing the major clients and ecosystem stakeholders etc:

 - Are positive towards the EIP,
 - Would accept (well written) PRs to include the EIP into the codebase.
    - So that it could be toggled on for testing…
    - …but not with an actual block number for activation

## Motivation

Development of clear specifications and pull requests to existing Ethereum Clients is a large investment of time and resources. The state of *Eligible for Inclusion* is a signal from the Ethereum Core Developers to an EIP Author validiating the idea behind an EIP and  confirms investing their time further pursing it is worthwhile.

## Specification

| EIP      | Title                              | Pipeline Status | Date of Initial Decision | REF |
| -------- | ----------------------------------------------------- | -------- | ---------- | ---- | 
| EIP-663  | Unlimited SWAP and DUP instructions                   | ELIGIBLE | 2019-11-01 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2074.md) |
| EIP-1057  | ProgPoW, a Programmatic Proof-of-Work                   | ELIGIBLE | 2019-11-01 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2074.md) |
| EIP-1380 | Reduced gas cost for call to self                     | ELIGIBLE | 2019-11-01 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2074.md) |
| EIP-1559 | Fee market change for ETH 1.0 chain                   | ELIGIBLE | 2019-11-01 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2074.md) |
| EIP-1702 | Generalized Account Versioning Scheme                 | ELIGIBLE | 2019-11-01 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2074.md) |
| EIP-1962 | EC arithmetic and pairings with runtime definitions   | ELIGIBLE | 2019-11-01 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2074.md) |
| EIP-1985 | Sane limits for certain EVM parameters                | ELIGIBLE | 2019-11-01 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2074.md) |
| EIP-2046 | Reduced gas cost for static calls made to precompiles | ELIGIBLE | 2019-11-01 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2074.md) |
| EIP-2315 | Simple Subroutines for the EVM                        | ELIGIBLE | 2020-02-21 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2081.md#decisions) |
| EIP-2537 | Precompile for BLS12-381 curve operations             | ELIGIBLE | 2020-03-06 | [🔗](https://github.com/ethereum/pm/blob/master/All%20Core%20Devs%20Meetings/Meeting%2082.md) |

## Rationale

**EIP Number**

**Title**

**Pipeline Status** : Show the current status in the context of the EIP centric model. The list is sorted by furthest along in the process.

**Date of Initial Decision** : Date of the initial decision for Eligibility for Inclusion

**REF** : Link to the decision on the AllCoreDevs Notes


## References

 - EIP Centric Forking Model Proposal by @holiman - https://notes.ethereum.org/@holiman/S1ELAYY7S?type=view



## Copyright
Copyright and related rights waived via [CC0](../LICENSE.md).
