---
eip: 2681
title: Limit account nonce to 2^64-1
author: Alex Beregszaszi (@axic)
discussions-to: https://ethereum-magicians.org/t/eip-2681-limit-account-nonce-to-2-64-1/4324
status: Final
type: Standards Track
category: Core
created: 2020-04-25
---

## Abstract

Limit account nonce to be between `0` and `2^64-1`.

## Motivation

Account nonces are currently specified to be arbitrarily long unsigned integers. Dealing with arbitrary length data in the state witnesses is not optimal, therefore this EIP will allow proofs to represent the nonce in a more optimized way.

Additionally it could prove beneficial to transaction formats, where some improvements are potentially sought by at least three other proposals.

Lastly, this facilitates a minor optimisation in clients, because the nonce no longer needs to be kept as a 256-bit number.

## Specification

Introduce two new restrictions retroactively from genesis:

1. Consider any transaction invalid, where the nonce exceeds or equals to `2^64-1`.
2. The `CREATE` and `CREATE2` instructions' execution ends with the result `0` pushed on stack, where the account nonce is `2^64-1`. Gas for initcode execution is not deducted in this case.

## Rationale

1. It is unlikely for any nonce to reach or exceed the proposed limit. If one would want to reach that limit via external transactions, it would cost at least `21000 * (2^64-1) = 387_381_625_547_900_583_915_000` gas.

2. It must be noted that in the past, in the Morden testnet, each new account had a starting nonce of `2^20` in order to differentiate transactions from mainnet transactions.
This mode of replay protection is out of fashion since [EIP-155](./eip-155.md) introduced a more elegant way using chain identifiers.

3. Most clients already consider the nonce field to be 64-bit, such as go-ethereum.

4. The reason a transaction with nonce `2^64-1` is invalid, because otherwise after inclusion the sender account's nonce would exceed `2^64-1`.

## Backwards Compatibility

While this is a breaking change, no actual effect should be visible:

1. There is no account in the state currently which would have a nonce exceeding that value. As of November 2020, the account `0xea674fdde714fd979de3edf0f56aa9716b898ec8` is responsible for the highest account nonce at approximately 29 million.

2. go-ethereum already has this restriction partially in place (`state.Account.Nonce` and `types.txdata.AccountNonce` it as a 64-bit number).

## Security Considerations

None.

## Copyright

Copyright and related rights waived via [CC0](../LICENSE.md).
